@@ -108,3 +108,7 @@ class BirthdayModel(BaseBirthdayModel):
 
     class Meta:
         abstract = True
+
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        # super(BirthdayModel, self).__init__(*args, **kwargs)
